@@ -63,7 +63,8 @@ enable <- function() {
       bins <- pkgs[tolower(pkgs) %in% row.names(dbb)]
       srcs <- pkgs[! pkgs %in% bins]
       binvers <- dbb[tolower(bins), "Version"]
-      srcvers <- dbs[bins, "Version"]
+      srcvers <- sapply(bins, function(bin) # may not be in dbs
+        if (bin %in% row.names(dbs)) dbs[bin, "Version"] else "0")
       later <- as.numeric_version(binvers) < srcvers
 
       # determine whether later versions should be installed
@@ -99,8 +100,10 @@ enable <- function() {
     } else if (type == "binary-source") {
       # install as many binaries as possible and fallback to source
       if (length(pkgs <- bspm::install_sys(pkgs))) {
+        dbs <- available.packages(contriburl=contriburl, method=method,
+                                  type="source", ...)
         inst <- row.names(installed.packages(.Library.site, ...))
-        deps <- tools::package_dependencies(pkgs, recursive=TRUE)
+        deps <- tools::package_dependencies(pkgs, dbs, recursive=TRUE)
         deps <- lapply(deps, function(x) setdiff(x, inst))
         deps <- unique(unlist(deps, use.names=FALSE))
         if (length(deps)) bspm::install_sys(deps)
